@@ -2,7 +2,7 @@ package XML::Compile::SOAP::Daemon::Dancer2;
 use strict;
 use warnings;
 use 5.008_005;
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 use Dancer2::Plugin;
 use Dancer2::FileUtils 'path';
 use Class::Load qw(try_load_class);
@@ -159,6 +159,10 @@ operations: each sub will be called with parameters: $soap, $data, $dsl
 
 Pierre VIGIER E<lt>pierre.vigier@gmail.comE<gt>
 
+=head1 CONTRIBUTORS
+
+Mohamad Hallal E<lt>https://github.com/mohdhallal<gt>
+
 =head1 COPYRIGHT
 
 Copyright 2016- Pierre VIGIER
